=== modified file 'bzrlib/export/dir_exporter.py'
--- bzrlib/export/dir_exporter.py	2011-03-13 19:10:45 +0000
+++ bzrlib/export/dir_exporter.py	2011-03-13 21:30:33 +0000
@@ -27,7 +27,7 @@
     )
 
 
-def dir_exporter(tree, dest, root, subdir, filtered=False, force_mtime=None):
+def dir_exporter(tree, dest, root, subdir=None, filtered=False, force_mtime=None):
     """Export this tree to a new directory.
 
     `dest` should either not exist or should be empty. If it does not exist it

=== modified file 'bzrlib/export/tar_exporter.py'
--- bzrlib/export/tar_exporter.py	2011-03-13 21:04:10 +0000
+++ bzrlib/export/tar_exporter.py	2011-03-13 21:30:33 +0000
@@ -32,7 +32,7 @@
     )
 
 
-def export_tarball(tree, ball, root, subdir, filtered=False,
+def export_tarball(tree, ball, root, subdir=None, filtered=False,
                    force_mtime=None):
     """Export tree contents to a tarball.
 

=== modified file 'bzrlib/export/zip_exporter.py'
--- bzrlib/export/zip_exporter.py	2011-03-13 19:26:35 +0000
+++ bzrlib/export/zip_exporter.py	2011-03-13 21:30:33 +0000
@@ -44,7 +44,7 @@
 _DIR_ATTR = stat.S_IFDIR | ZIP_DIRECTORY_BIT | DIR_PERMISSIONS
 
 
-def zip_exporter(tree, dest, root, subdir, filtered=False, force_mtime=None):
+def zip_exporter(tree, dest, root, subdir=None, filtered=False, force_mtime=None):
     """ Export this tree to a new zip file.
 
     `dest` will be created holding the contents of this tree; if it
@@ -55,7 +55,6 @@
     if dest == "-":
         dest = sys.stdout
     zipf = zipfile.ZipFile(dest, "w", compression)
-
     try:
         for dp, ie in _export_iter_entries(tree, subdir):
             file_id = ie.file_id

=== modified file 'bzrlib/tests/blackbox/test_export.py'
--- bzrlib/tests/blackbox/test_export.py	2011-03-13 21:23:13 +0000
+++ bzrlib/tests/blackbox/test_export.py	2011-03-13 21:30:33 +0000
@@ -356,7 +356,5 @@
         tree.commit('setup', timestamp=315532800)
         self.run_bzr('export --per-file-timestamps test.zip branch')
         zfile = zipfile.ZipFile('test.zip')
-        # Make sure the zipfile contains 'a', but does not contain
-        # '.bzrignore'.
         info = zfile.getinfo("test/har")
         self.assertEquals((1980, 1, 1, 1, 0, 0), info.date_time)

=== modified file 'bzrlib/tests/test_export.py'
--- bzrlib/tests/test_export.py	2011-03-13 21:11:26 +0000
+++ bzrlib/tests/test_export.py	2011-03-13 21:30:33 +0000
@@ -20,6 +20,7 @@
 import os
 import tarfile
 import time
+import zipfile
 
 from bzrlib import (
     errors,
@@ -191,3 +192,18 @@
             wt.unlock()
         self.assertEquals(["bar/a"], ball.getnames())
         ball.close()
+
+
+class ZipExporterTests(tests.TestCaseWithTransport):
+
+    def test_per_file_timestamps(self):
+        tree = self.make_branch_and_tree('.')
+        self.build_tree_contents([('har', 'foo')])
+        tree.add('har')
+        # Earliest allowable date on FAT32 filesystems is 1980-01-01
+        tree.commit('setup', timestamp=315532800)
+        export.export(tree.basis_tree(), 'test.zip', format='zip',
+            per_file_timestamps=True)
+        zfile = zipfile.ZipFile('test.zip')
+        info = zfile.getinfo("test/har")
+        self.assertEquals((1980, 1, 1, 1, 0, 0), info.date_time)

